 # -*- coding: utf-8 -*-
"""
Spyder Editor

This is a temporary script file.
"""

import pyqtgraph as pg
from ADoutputs import daq_AO, daq_DO
from pyqtgraph.Qt import QtGui
from PyQt5.QtCore import QBasicTimer
from PyQt5.QtWidgets import (QPushButton, QWidget)


#An example of a class
class anal_control_signal(QWidget):
    _registry = []
    
    def __init__(self, name, channel, out_minimum = -10, out_maximum = 10, out_step = 0.1):
        super().__init__()
        
        self._registry.append(self)
        
        self.name = name
        self.ch = channel
        
        self.initial_value = 0
        self.max = out_maximum
        self.min = out_minimum
        self.step = out_step
        self.siPrefix = True
        self.suffix = 'V'

        self.sb = pg.SpinBox(value = self.initial_value, bounds=[self.min, self.max], step = self.step, siPrefix = self.siPrefix, suffix = self.suffix)
        
        self.AO = daq_AO(self.ch)
    
        self.scan_button = QPushButton('Start scan')
        
        self.timer = QBasicTimer()
        self.scan_step = 0

        self.scan_sb_start =  pg.SpinBox(value = 0, bounds=[self.min, self.max], step = self.step, siPrefix = self.siPrefix, suffix = self.suffix)
        self.scan_sb_stop =    pg.SpinBox(value = 0, bounds=[self.min, self.max], step = self.step, siPrefix = self.siPrefix, suffix = self.suffix)
        self.scan_sb_period = pg.SpinBox(value = 1, bounds=[0, 100], step = 0.1, siPrefix = True, suffix = 's')
        
        self.scan_direction = 0
        
        self.scan_button.clicked.connect(self.doAction)
        self.sb.sigValueChanging.connect(self.sb_analog_change)
        
        self.spin_boxes = [('sb', self.sb), ('scan_sb_start', self.scan_sb_start), ('scan_sb_stop', self.scan_sb_stop), ('scan_sb_period', self.scan_sb_period)]
        
        
        
    def sb_analog_change(self):
        self.AO.set_out(self.sb.val)
        
    def set_name(self, name):
        self.name = name
    
    def set_initial_value(self, value):
        self.initial_value = value
        
    
        
    def set_siPrefix(self, value):
        self.siPrefix = value
    
    def set_sufix(self, value):
        self.sufix = value
    
   
        
    def timerEvent(self, e):
        if abs(abs(self.scan_step)-abs(float(self.scan_sb_start.val)))<1e-6 or abs(abs(self.scan_step)-abs(float(self.scan_sb_stop.val)))<1e-6:
            self.scan_direction = (-1) * self.scan_direction
            
        #print(self.scan_step, float(self.scan_sb_start.val), abs(self.scan_step-float(self.scan_sb_stop.val)))
        self.scan_step = self.scan_step + self.scan_direction
        self.AO.set_out(self.scan_step)
        

    def doAction(self):
        
        self.scan_direction = -float( (self.scan_sb_stop.val-self.scan_sb_start.val)/self.scan_sb_period.val ) * float(2 * 1e-3)
        self.scan_step = float(self.scan_sb_start.val)
        
        if self.timer.isActive():
            self.timer.stop()
            self.scan_button.setText('Start scan')
            self.scan_button.setStyleSheet('background-color: None')
            
            self.scan_step = 0
            self.AO.set_out(self.sb.val)
        else:
            self.scan_button.setStyleSheet("background-color: green")
            self.timer.start(1, self)
            self.scan_button.setText('Scanning')
            

    
        
        

            
class digital_control_signal(QWidget):
    
    def __init__(self, name, channel):
        self.name = name
        self.ch = channel
        
        self.initial_value = 0
        self.DO = daq_DO(self.ch)
        
        self.cb = QtGui.QCheckBox()
        
    def set_name(self, name):
        self.name = name
    
    def set_initial_value(self, value):
        self.initial_value = value